==> nextcloud-30.0.12.tgz: nextcloud/apps/serverinfo/l10n/mk.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Информациите за процесорот не се достапни",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Вкупно: {memTotalBytes}/Моментално искористување: {memUsageBytes}",
    "RAM info not available" : "Информации за RAM меморијата не се достапни",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Вкупно: {swapTotalBytes}/Моментално искористување: {swapUsageBytes}",
    "SWAP info not available" : "Информации за SWAP меморијата не се достапни",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не е поддржано!",
    "Press ⌘-C to copy." : "Притисни ⌘-C за да копираш",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за да копираш.",
    "System" : "Систем",
    "Monitoring" : "Следење",
    "Monitoring app with useful server information" : "Апликација за мониторирање и корисни информации за серверот",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Овозможува корисни информации за серверот, како искористеност на процесорот, искористеност на меморијата, искористеност на просторот на дискот, број на корисници, итн.",
    "Operating System:" : "Оперативен систем",
    "CPU:" : "Процесор:",
    "Unknown Processor" : "Непознат процесор",
    "Memory:" : "Меморија:",
    "Server time:" : "Време на серверот:",
    "Uptime:" : "Време на работа:",
    "Temperature" : "Температура",
    "Load" : "Искористеност",
    "Memory" : "Меморија",
    "Disk" : "Диск",
    "Mount:" : "Монтиран:",
    "Filesystem:" : "Податочен систем:",
    "Size:" : "Големина:",
    "Available:" : "Достапно:",
    "Used:" : "Искористено:",
    "Files:" : "Датотеки:",
    "Storages:" : "Складишта:",
    "Free Space:" : "Слободен простор:",
    "Network" : "Мрежа",
    "Hostname:" : "Име на серверот:",
    "Gateway:" : "Gateway:",
    "Status:" : "Статус:",
    "Speed:" : "Брзина:",
    "Duplex:" : "Дуплекс:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Активни корисници",
    "Shares" : "Споделувања",
    "Users:" : "Корисници:",
    "Groups:" : "Групи:",
    "Links:" : "Линкови:",
    "Emails:" : "Е-пошти:",
    "Federated sent:" : "Федерални испраќања:",
    "Federated received:" : "Федерални примања:",
    "Talk conversations:" : "Talk разговори:",
    "PHP" : "PHP",
    "Version:" : "Верзија:",
    "Memory limit:" : "Лимит на меморијата:",
    "Max execution time:" : "Максимално време на извршување:",
    "Upload max size:" : "Максимална големина на прикачување:",
    "OPcache Revalidate Frequency:" : "Фреквенција на ревалидација на OPcache:",
    "Extensions:" : "Екстензија:",
    "Unable to list extensions" : "Неможе да се излистаат екстензиите",
    "Show phpinfo" : "Прикажи phpinfo",
    "Database" : "База",
    "Type:" : "Вид:",
    "External monitoring tool" : "Надворешен уред за следење",
    "Copy" : "Копирај",
    "To use an access token, please generate one then set it using the following command:" : "За да користите токен за пристап, ве молиме генерирајте еден, а потоа поставете го користејќи ја следнава команда:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Потоа поминете го токенот со заглавието „NC-Token“ кога го барате горното URL."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-31.0.10.tgz: nextcloud/apps/serverinfo/l10n/mk.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Информациите за процесорот не се достапни",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Вкупно: {memTotalBytes}/Моментално искористување: {memUsageBytes}",
    "RAM info not available" : "Информации за RAM меморијата не се достапни",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Вкупно: {swapTotalBytes}/Моментално искористување: {swapUsageBytes}",
    "SWAP info not available" : "Информации за SWAP меморијата не се достапни",
    "Copied!" : "Копирано!",
    "Not supported!" : "Не е поддржано!",
    "Press ⌘-C to copy." : "Притисни ⌘-C за да копираш",
    "Press Ctrl-C to copy." : "Притисни Ctrl-C за да копираш.",
    "System" : "Систем",
    "Monitoring" : "Следење",
    "Monitoring app with useful server information" : "Апликација за мониторирање и корисни информации за серверот",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Овозможува корисни информации за серверот, како искористеност на процесорот, искористеност на меморијата, искористеност на просторот на дискот, број на корисници, итн.",
    "Operating System:" : "Оперативен систем",
    "CPU:" : "Процесор:",
    "Memory:" : "Меморија:",
    "Server time:" : "Време на серверот:",
    "Uptime:" : "Време на работа:",
    "Temperature" : "Температура",
    "Load" : "Искористеност",
    "Memory" : "Меморија",
    "Disk" : "Диск",
    "Mount:" : "Монтиран:",
    "Filesystem:" : "Податочен систем:",
    "Size:" : "Големина:",
    "Available:" : "Достапно:",
    "Used:" : "Искористено:",
    "Files:" : "Датотеки:",
    "Storages:" : "Складишта:",
    "Free Space:" : "Слободен простор:",
    "Network" : "Мрежа",
    "Hostname:" : "Име на серверот:",
    "Gateway:" : "Gateway:",
    "Status:" : "Статус:",
    "Speed:" : "Брзина:",
    "Duplex:" : "Дуплекс:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Активни корисници",
    "Shares" : "Споделувања",
    "Users:" : "Корисници:",
    "Groups:" : "Групи:",
    "Links:" : "Линкови:",
    "Emails:" : "Е-пошти:",
    "Federated sent:" : "Федерални испраќања:",
    "Federated received:" : "Федерални примања:",
    "Talk conversations:" : "Talk разговори:",
    "PHP" : "PHP",
    "Version:" : "Верзија:",
    "Memory limit:" : "Лимит на меморијата:",
    "Max execution time:" : "Максимално време на извршување:",
    "Upload max size:" : "Максимална големина на прикачување:",
    "OPcache Revalidate Frequency:" : "Фреквенција на ревалидација на OPcache:",
    "Extensions:" : "Екстензија:",
    "Unable to list extensions" : "Неможе да се излистаат екстензиите",
    "Show phpinfo" : "Прикажи phpinfo",
    "Database" : "База",
    "Type:" : "Вид:",
    "External monitoring tool" : "Надворешен уред за следење",
    "Copy" : "Копирај",
    "To use an access token, please generate one then set it using the following command:" : "За да користите токен за пристап, ве молиме генерирајте еден, а потоа поставете го користејќи ја следнава команда:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Потоа поминете го токенот со заглавието „NC-Token“ кога го барате горното URL.",
    "Unknown Processor" : "Непознат процесор"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
